# -----------------------------------------------------------------------------
sub infLlogs
# This routine must follow DBSpaces
{
  ($thishost) = @_;

  if ($up[$thishost] ne "Y")
  {
    logit("(Down/Inhibited)",$thishost);
    return 1;
  }

  if ($db_status[$thishost] eq "R")
  {
    logit("HDR Secondary Instance - llog checking not applicable",$thishost);
    return 1;
  }
    
  #
  # Check to see if LTAPEDEV is set to /dev/null
  #

  if ($ltapedev[$thishost] eq "/dev/null")
  {
    logit("onconfig LTAPEDEV=/dev/null - Log check not applicable",$thishost);
    return 1;
  }

  if ($t_logfull_w[$thishost] eq "") { $t_logfull_w[$thishost] = 60; }
  if ($t_logfull_c[$thishost] eq "") { $t_logfull_c[$thishost] = 70; }

  #
  # Run onstat -l
  #

  if ($sw_version[$thishost] gt "7.10.UC2")
  {
    #
    # Informix >= V7
    #
    remsh("onstat -;export PATH=\$PATH:$infdir[$thishost]/bin;ksh $probe_dir[$thishost]/dbamon_check_logs.sh",$tmpfl2,$thishost);
  }
  else
  {
    #
    # Informix < V7
    #
    remsh("onstat -l",$tmpfl2,$thishost);
    if ($rc_save) { return 1 }
    if (system("grep -i 'shared memory not' $tmpfl2") == 0) 
    {
      &logit("(Down/Inhibited)",$thishost);
      return 1;
    }
  }

  ##system("cat $tmpfl2");

  if (system("grep 'Fatal' $tmpfl2 > /dev/null 2>&1") == 0) 
  {
    &event("C",$thishost,"Fatal dbaccess Error Checking Logical Logs","LLogErr","DBA231C",$tmpfl2);
    return 1;
  }

  $num_llogs  = 0;
  $full_llogs = 0;

  $stop = 0;

  open(TMPFL2, "$tmpfl2"  ) || &error_msg("Can't open input $tmpfl2 - $!");
  while(<TMPFL2>)
  {
    &parse;
    if ($NF == 8 && $F1 ne "address" && length($F3) == 7 && $F1 ne "Buffer")
    {
      $llog_flags = $F3;
      $num_llogs++;
      if (index($llog_flags,"U") > -1) { $full_llogs++; }
    }
  }
  close(TMPFL2);

  if ($num_llogs == 0)
  {
    $msg = sprintf("infLlogs() - %s - zero divide #3\n",$title[$thishost]);
    &logit($msg,$thishost);
    system("cat $tmpfl2");
    &error_msg($msg,$thishost);
    return 1;
  }

  $logpct = sprintf "%.2f",(($full_llogs / $num_llogs) * 100);

  if ($logpct > $t_logfull_c[$thishost])
  {
    &event("C",$thishost,"Total llog files=$num_llogs Full llog files=$full_llogs (${logpct}% - Critical Threshold=${t_logfull_c[$thishost]}%) ","LLog","DBA230",$tmpfl2);
  }
  elsif ($logpct > $t_logfull_w[$thishost])
  {
    &event("W",$thishost,"Total llog files=$num_llogs Full llog files=$full_llogs (${logpct}% - Warning Threshold=${t_logfull_w[$thishost]}%) ","LLog","DBA230",$tmpfl2);
  }
  else
  {
    $msg = sprintf("OK (%s/%s) %s%% - C_Threshold=${t_logfull_c[$thishost]}% W_Threshold=${t_logfull_w[$thishost]}%",$full_llogs,$num_llogs,$logpct);
    &logit($msg,$thishost);
  }

  &logDetails($thishost,"<h3>Informix Logical Log Status</h3>");
  &logDetails($thishost,"<table border=1 bgcolor=$table_bgcolor>");
  &logDetails($thishost,"<tr bgcolor=slate><th>Parameter<th>Value<th>Comments</tr>");
  &logDetails($thishost,"<tr><td>$f_s Number of Logical Log Files:<td align=right>$f_s $num_llogs");
  &logDetails($thishost,"<tr><td>$f_s Number of Full Logical Log Files:<td align=right>$f_s $full_llogs");
  &logDetails($thishost,"<tr><td>$f_s Percent of Logical Log Files That Are Full:<td align=right>$f_s ${logpct}%");
  &logDetails($thishost,"</table><hr>");
}
# -----------------------------------------------------------------------------
1;
